"use strict";

var _react = _interopRequireDefault(require("react"));
var _react2 = require("@testing-library/react");
var _Highlight = _interopRequireDefault(require("../Highlight.js"));
var _defaultProps = _interopRequireDefault(require("../../defaultProps.js"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
var exampleCode = "\n(function someDemo() {\n  var test = \"Hello World!\";\n  console.log(test);\n})();\n\nreturn () => <App />;\n".trim();
describe("<Highlight />", function () {
  afterEach(_react2.cleanup);
  describe("snapshots", function () {
    it("renders correctly", function () {
      var _render = (0, _react2.render)( /*#__PURE__*/_react["default"].createElement(_Highlight["default"], _extends({}, _defaultProps["default"], {
          code: exampleCode,
          language: "jsx"
        }), function (_ref) {
          var className = _ref.className,
            style = _ref.style,
            tokens = _ref.tokens,
            getLineProps = _ref.getLineProps,
            getTokenProps = _ref.getTokenProps;
          return /*#__PURE__*/_react["default"].createElement("pre", {
            className: className,
            style: style
          }, tokens.map(function (line, i) {
            return /*#__PURE__*/_react["default"].createElement("div", getLineProps({
              line: line,
              key: i
            }), line.map(function (token, key) {
              return /*#__PURE__*/_react["default"].createElement("span", getTokenProps({
                token: token,
                key: key
              }));
            }));
          }));
        })),
        container = _render.container;
      expect(container).toMatchSnapshot();
    });
    it("renders unsupported languages correctly", function () {
      var _render2 = (0, _react2.render)( /*#__PURE__*/_react["default"].createElement(_Highlight["default"], _extends({}, _defaultProps["default"], {
          code: exampleCode,
          language: "abcdefghijklmnop"
        }), function (_ref2) {
          var className = _ref2.className,
            style = _ref2.style,
            tokens = _ref2.tokens,
            getLineProps = _ref2.getLineProps,
            getTokenProps = _ref2.getTokenProps;
          return /*#__PURE__*/_react["default"].createElement("pre", {
            className: className,
            style: style
          }, tokens.map(function (line, i) {
            return /*#__PURE__*/_react["default"].createElement("div", getLineProps({
              line: line,
              key: i
            }), line.map(function (token, key) {
              return /*#__PURE__*/_react["default"].createElement("span", getTokenProps({
                token: token,
                key: key
              }));
            }));
          }));
        })),
        container = _render2.container;
      expect(container).toMatchSnapshot();
    });
    it("renders without style props when no theme is passed", function () {
      var _render3 = (0, _react2.render)( /*#__PURE__*/_react["default"].createElement(_Highlight["default"], _extends({}, _defaultProps["default"], {
          theme: undefined,
          code: exampleCode,
          language: "jsx"
        }), function (_ref3) {
          var className = _ref3.className,
            style = _ref3.style,
            tokens = _ref3.tokens,
            getLineProps = _ref3.getLineProps,
            getTokenProps = _ref3.getTokenProps;
          return /*#__PURE__*/_react["default"].createElement("pre", {
            className: className,
            style: style
          }, tokens.map(function (line, i) {
            return /*#__PURE__*/_react["default"].createElement("div", getLineProps({
              line: line,
              key: i
            }), line.map(function (token, key) {
              return /*#__PURE__*/_react["default"].createElement("span", getTokenProps({
                token: token,
                key: key
              }));
            }));
          }));
        })),
        container = _render3.container;
      expect(container.innerHTML.includes("style")).toBeFalsy();
    });
  });
  describe("getLineProps", function () {
    it("transforms lineProps inputs correctly", function () {
      var input = {
        key: "line-1",
        style: {
          cssProp: "test"
        },
        className: "line-class",
        line: [{
          types: ["punctuation"],
          content: "!"
        }],
        restPropsTest: true
      };
      (0, _react2.render)( /*#__PURE__*/_react["default"].createElement(_Highlight["default"], _extends({}, _defaultProps["default"], {
        code: exampleCode,
        language: "jsx"
      }), function (_ref4) {
        var getLineProps = _ref4.getLineProps;
        var output = getLineProps(input);
        expect(output).toEqual({
          key: "line-1",
          style: {
            cssProp: "test",
            backgroundColor: null,
            color: expect.any(String)
          },
          className: "token-line line-class",
          restPropsTest: true
        });
        return null;
      }));
    });
  });
  describe("getTokenProps", function () {
    it("transforms tokenProps inputs correctly", function () {
      var input = {
        key: "token-1",
        style: {
          cssProp: "test"
        },
        className: "token-class",
        token: {
          types: ["punctuation"],
          content: "!"
        },
        restPropsTest: true
      };
      (0, _react2.render)( /*#__PURE__*/_react["default"].createElement(_Highlight["default"], _extends({}, _defaultProps["default"], {
        code: exampleCode,
        language: "jsx"
      }), function (_ref5) {
        var getTokenProps = _ref5.getTokenProps;
        var output = getTokenProps(input);
        expect(output).toEqual({
          key: "token-1",
          style: {
            cssProp: "test",
            color: expect.any(String)
          },
          className: "token punctuation token-class",
          restPropsTest: true,
          children: "!"
        });
        return null;
      }));
    });
    it("transforms constructor token style correctly", function () {
      // From https://github.com/FormidableLabs/prism-react-renderer/issues/11
      (0, _react2.render)( /*#__PURE__*/_react["default"].createElement(_Highlight["default"], _extends({}, _defaultProps["default"], {
        code: "open Common;",
        language: "reason"
      }), function (_ref6) {
        var tokens = _ref6.tokens,
          getTokenProps = _ref6.getTokenProps;
        var line = tokens[0];
        var token = line[2];
        var output = getTokenProps({
          token: token,
          key: 2
        });
        expect(typeof output.style).not.toBe("function");
        return null;
      }));
    });
  });
});